package com.vendor.burn.commands;

package .var.folders.cl.9twcgjfx4vsg5zl73c6wxmvm0000gn.T;

import com.vendor.burn.commands.SerialCommand;
import com.vendor.burn.model.LocalConfig;
import com.vendor.burn.model.config.BurnConfig;
import com.vendor.burn.model.config.PreferenceConfig;
import com.vendor.burn.preferences.FastbootPreferences;
import com.vendor.burn.utilitily.ToolUtils;
import com.vendor.burn.views.FastbootView;
import java.io.File;

public class TFTPCommand extends SerialCommand {
  private static final String KEY_TFTP = "tftp";
  
  private static final String KEY_TFTPPUT = "tftpput";
  
  private TFTPCommand(String command) {
    setCommand(command);
  }
  
  public static com.vendor.burn.commands.TFTPCommand download(File file, String address) {
    StringBuilder sb = new StringBuilder();
    sb.append("tftp").append(" ");
    if (!address.startsWith("0x"))
      sb.append("0x"); 
    String serviceFileDirectory = "";
    LocalConfig localConfig = BurnConfig.getLocalConfig();
    if (localConfig != null) {
      boolean isRemoteTftpServer = localConfig.isRemoteTftpServer();
      String remoteTftpServerDir = localConfig.getRemoteTftpServerDir();
      if (isRemoteTftpServer && remoteTftpServerDir != null)
        serviceFileDirectory = remoteTftpServerDir; 
    } 
    sb.append(address).append(" ").append(serviceFileDirectory + serviceFileDirectory);
    com.vendor.burn.commands.TFTPCommand tftpCommand = new com.vendor.burn.commands.TFTPCommand(sb.toString());
    tftpCommand.setTimeout(calculateTimeout(file.length()));
    return tftpCommand;
  }
  
  private static int calculateTimeout(long length) {
    int speed = 0;
    if (ToolUtils.isCmdLine()) {
      speed = PreferenceConfig.getTftpSpeed();
    } else {
      speed = FastbootPreferences.getInt("vendor.burn.tftp.speed");
    } 
    if (speed == 0)
      speed = 1024; 
    int tftpDownloadTimeout = 0;
    tftpDownloadTimeout = (int)((length / speed + 2L) * 1000L);
    if (tftpDownloadTimeout < 1800000)
      return tftpDownloadTimeout; 
    return (int)(length / (speed * 500) + 1000L) * 1000;
  }
  
  public static com.vendor.burn.commands.TFTPCommand upload(File file, String address, String length) {
    StringBuilder sb = new StringBuilder();
    if (FastbootView.isChipBranchSeries9()) {
      sb.append("tftpput").append(" ");
    } else {
      sb.append("tftp").append(" ");
    } 
    if (!address.startsWith("0x"))
      sb.append("0x"); 
    if (FastbootView.isChipBranchSeries9()) {
      sb.append(address).append(" ");
      if (!length.startsWith("0x"))
        sb.append("0x"); 
      sb.append(length).append(" ").append(file.getName());
    } else {
      sb.append(address).append(" ").append(file.getName()).append(" ");
      if (!length.startsWith("0x"))
        sb.append("0x"); 
      sb.append(length);
    } 
    com.vendor.burn.commands.TFTPCommand tftpCommand = new com.vendor.burn.commands.TFTPCommand(sb.toString());
    tftpCommand.setTimeout(calculateTimeout(getLength(length).longValue()));
    return tftpCommand;
  }
}
